"use client";
import { urlImage } from "@/lib/urlIMG";
import {GoArrowRight, GoArrowLeft} from "react-icons/go";
import {Swiper, SwiperSlide} from "swiper/react";
import {EffectFade} from "swiper/modules";

import "swiper/css";
import "swiper/css/effect-fade";

import Lightbox from "yet-another-react-lightbox";
import Captions from "yet-another-react-lightbox/plugins/captions";
import Thumbnails from "yet-another-react-lightbox/plugins/thumbnails";
import Counter from "yet-another-react-lightbox/plugins/counter";

import "yet-another-react-lightbox/styles.css";
import "yet-another-react-lightbox/plugins/thumbnails.css";
import "yet-another-react-lightbox/plugins/counter.css";
import "yet-another-react-lightbox/plugins/captions.css";

import Image from "next/image";
import ArrowBtn from "./arrow-btn";
import {useState} from "react";

interface Props {
  img: any;
}

export default function ImgContentWidget({img}: Props) {
  const [open, setOpen] = useState(false);
  const [index, setIndex] = useState(0);

  return (
    <>
      <Swiper
        modules={[EffectFade]}
        effect="fade"
        spaceBetween={50}
        slidesPerView={1}
        loop={true}
        className="h-fit lg:h-full cursor-pointer"
      >
        {img.map((item: any, index: number) => (
          <SwiperSlide
            key={index}
            onClick={() => {
              setIndex(index), setOpen(true);
            }}
          >
            <Image
              src={item}
              alt='Villa Batu'
              width={1500}
              height={1000}
              className="object-cover w-full h-[350px] lg:h-full max-h-screen"
            />
          </SwiperSlide>
        ))}
        <div className="w-full">
          <div className="absolute top-1/2 left-10 transform -translate-x-1/2 -translate-y-1/2 z-50 w-20 h-20 flex justify-center items-center">
            <ArrowBtn
              icon={<GoArrowLeft className="text-white" size={30} />}
              position="left"
            />
          </div>
          <div className="absolute top-1/2 -right-10 transform -translate-x-1/2 -translate-y-1/2 z-50 w-20 h-20 flex justify-center items-center">
            <ArrowBtn
              icon={<GoArrowRight className="text-white" size={30} />}
              position="right"
            />
          </div>
        </div>
      </Swiper>

      <Lightbox
        index={index}
        open={open}
        plugins={[Thumbnails, Captions, Counter]}
        close={() => setOpen(false)}
        slides={img.map((item: any, idx: number) => ({
          src: item,
          key: idx,
        }))}
        counter={{container: {style: {top: "unset", bottom: 0}}}}
        controller={{closeOnPullDown: true, closeOnBackdropClick: true}}
      />
    </>
  );
}
